							  /******************** (C) COPYRIGHT 2010 STMicroelectronics ********************
* File Name          : hw_config.h
* Author             : MCD Application Team
* Version            : V3.1.1
* Date               : 04/07/2010
* Description        : Hardware Configuration & Setup
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __INTERNAL_FLASH_H
#define __INTERNAL_FLASH_H

/******************************************************************************************************/
/*                                              Includes                                              */
/******************************************************************************************************/
#include "stdint.h"
#include "eeprom.h"


/******************************************************************************************************/
/* Festlegen, ob Variablen und Funktionen als "extern" deklariert werden muessen                      */
/******************************************************************************************************/
#ifdef __INTERNAL_FLASH_C
  #define LINKTYPE_INTERNAL_FLASH  
#else
  #define LINKTYPE_INTERNAL_FLASH extern
#endif // #ifdef __INTERNAL_FLASH_C


/******************************************************************************************************/
/*                                           Globale Defines                                          */
/******************************************************************************************************/

#define MAX_TITELS 1
#define CELLS  MAX_TITELS*36

//Defines for EEPROM Save Function

#define  NUMBEROFTITELS		 0
							 
#define	 ChunkID_P1			  0
#define	 ChunkID_P2			  1
#define	 ChunkSize_P1		  2
#define	 ChunkSize_P2		  3
#define	 Format_P1			  4
#define	 Format_P2			  5
#define	 Subchunk1ID_P1		  6
#define	 Subchunk1ID_P2		  7
#define	 Subchunk1Size_P1	  8
#define	 Subchunk1Size_P2	  9
#define	 AudioFormat_P		 10
#define	 NumChannels_P		 11
#define	 SampleRate_P1		 12
#define	 SampleRate_P2		 13
#define	 ByteRate_P1		 14
#define	 ByteRate_P2		 15
#define	 BlockAlign_P		 16
#define	 BitsPerSample_P	 17
#define	 Subchunk2ID_P1		 18
#define	 Subchunk2ID_P2		 19
#define	 Subchunk2Size_P1	 20
#define	 Subchunk2Size_P2	 21
#define	 StartAdress_P1		 22
#define	 StartAdress_P2		 23
#define	 EndAdress_P1		 24
#define	 EndAdress_P2		 25
#define	 AudioStartAdress_P1 26
#define	 AudioStartAdress_P2 27
#define	 AudioEndAdress_P1	 28
#define	 AudioEndAdress_P2	 29
#define	 NumberOfSamples_P1	 30
#define	 NumberOfSamples_P2	 31
#define	 AdressOfLastFile_P1 32
#define	 AdressOfLastFile_P2 33
#define	 AdressOfNextFile_P1 34
#define	 AdressOfNextFile_P2 35

/*********************************************************************************************/
/*                              Globale Variablen                               */
/*********************************************************************************************/


LINKTYPE_INTERNAL_FLASH uint16_t u16VirtAddVarTab[CELLS];

/*********************************************************************************************/
/*                              Globale Strukturen                               */
/*********************************************************************************************/

/**
   Contains the Informations about the Titles
First Area Contains some informations about file
				
				* 	Endian		Offset		Fild Name			Fild Size		Description		
				* 	big			   0		ChunkID			    	4			contains "RIFF"	(0x52494646 big-endian form
				*	little		   4		ChunkSize				4			Size from her to end (36+Size2)
				*	big			   8		Format					4			contains "WAVE" (0x57415645 big-endian form)
				*	big			  12		Subchunk1ID				4			contains "fmt" (0x666d7420 big-endian form
				*	little		  16		Subchunk1Size			4			0xF by PCM
				*	little		  20		AudioFormat				2			PCM = 0x01 all others are Compressed
				*	little		  22		NumChannels				2			0x01 Mono 0x02 Stereo
				*	little		  24		SampleRate				4			8000, 44100, etc.
				*	little		  28		ByteRate				4		    == SampleRate * NumChannels * BitsPerSample/8
				*	little		  32		BlockAlign				2			== NumChannels * BitsPerSample/8
				*	little		  34		BitsPerSample			2			8 bits = 8, 16 bits = 16, etc.
				*	big			  36		Subchunk2ID				4			contains "data"	 (0x64617461 big-endian form)
				*	little		  40		Subchunk2Size			4			== NumSamples * NumChannels * BitsPerSample/8
				*	little		  44	   	Datas		   	  Subchunk2Size
**/
LINKTYPE_INTERNAL_FLASH struct AudioInformations
{
	uint32_t ChunkID;		   //2
	uint32_t ChunkSize;		   //2
	uint32_t Format;		   //2
	uint32_t Subchunk1ID;	   //2
	uint32_t Subchunk1Size;	   //2
	uint16_t AudioFormat;	   //1
	uint16_t NumChannels;	   //1
	uint32_t SampleRate;	   //2
	uint32_t ByteRate;		   //2
	uint16_t BlockAlign;	   //1
	uint16_t BitsPerSample;	   //1
	uint32_t Subchunk2ID;	   //2
	uint32_t Subchunk2Size;	   //2
	uint32_t StartAdress;	   //2
	uint32_t EndAdress;		   //2
	uint32_t AudioStartAdress; //2
	uint32_t AudioEndAdress;   //2
	uint32_t NumberOfSamples;  //2
	uint32_t AdressOfLastFile; //2
	uint32_t AdressOfNextFile; //2
}Titels[MAX_TITELS];  //64+	8 = 72 Byte je Strukt 2880Byte bei 40 Struckt  36Words



/*********************************************************************************************/
/*                              Globale Funktionsdeklarationen                               */
/*********************************************************************************************/
void set_ChunkID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_ChunkID (uint8_t Number);

void set_ChunkSize (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_ChunkSize (uint8_t Number);

void set_Format (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_Format (uint8_t Number);

void set_Subchunk1ID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_Subchunk1ID (uint8_t Number);

void set_Subchunk1Size (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_Subchunk1Size (uint8_t Number);

void set_AudioFormat (uint8_t Number, uint8_t Byte1, uint8_t Byte2);
uint16_t get_AudioFormat (uint8_t Number);

void set_NumChannels (uint8_t Number, uint8_t Byte1, uint8_t Byte2);
uint16_t get_NumChannels (uint8_t Number);

void set_SampleRate (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_SampleRate (uint8_t Number);

void set_ByteRate (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_ByteRate (uint8_t Number);

void set_BlockAlign (uint8_t Number, uint8_t Byte1, uint8_t Byte2);
uint16_t get_BlockAlign (uint8_t Number);

void set_BitsPerSample (uint8_t Number, uint8_t Byte1, uint8_t Byte2);
uint16_t get_BitsPerSample (uint8_t Number);

void set_Subchunk2ID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_Subchunk2ID (uint8_t Number);

void set_Subchunk2Size (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4);
uint32_t get_Subchunk2Size (uint8_t Number);

void set_StartAdress (uint8_t Number);
uint32_t get_StartAdress (uint8_t Number);

void set_EndAdress (uint8_t Number);
uint32_t get_EndAdress (uint8_t Number);

void set_AudioStartAdress (uint8_t Number);
uint32_t get_AudioStartAdress (uint8_t Number);

void set_AudioEndAdress (uint8_t Number);
uint32_t get_AudioEndAdress (uint8_t Number);

void set_NumberOfSamples (uint8_t Number);
uint32_t get_NumberOfSamples (uint8_t Number);

void set_AdressOfLastFile(uint8_t Number);
uint32_t get_AdressOfLastFile(uint8_t Number);

void set_AdressOfNextFile(uint8_t Number);
uint32_t get_AdressOfNextFile(uint8_t Number);

void StrucktSetCurrent (uint8_t Number, uint8_t *pt_Audio_Datas);
void StrucktClearAll (void);

void init_PageTabel (void);

uint8_t get_EEPROMNumberOfTitels(void);
void set_EEPROMNumberOfTitels (uint8_t Number);

void CopyStrucktToEEPROM (uint8_t Number);
void CopyEEPROMToStruckt (uint8_t Number);

void CopyStruck (uint8_t NumberOldStruckt, uint8_t NumberNewStruckt);
void ResetAdressDatas (uint8_t NumberNewStruckt);


#endif  /*__GLOBAL_H*/
/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/
