/******************** (C) COPYRIGHT 2008 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V2.0.1
* Date               : 06/13/2008
* Description        : Main program body
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

#define __DMA_USER_C

/******************************************************************************************************/
/*                                              Includes                                              */
/******************************************************************************************************/
#include "stm32f10x_dma.h"
#include "stm32f10x_tim.h"
#include "stm32f10x_spi.h"
#include "spi_flash.h"
#include "internal_flash.h"
#include "dma_user.h"
#include "timer_pwm.h"
#include "spi_flash.h"
#include "stream.h"
#include "math.h"



#pragma O3

/*********************************************************************************************/
/*                                    Modullokale Defines                                    */
/*********************************************************************************************/
#define SPI_MASTER_DR_Base  0x4001300C
#define TIM1_CCR1_Address   0x40012C34


/*********************************************************************************************/
/*                                   Modullokale Variablen                                   */
/*********************************************************************************************/
ErrorStatus HSEStartUpStatus_DMA;
TIM_TimeBaseInitTypeDef   TIM_TimeBaseStructure;
TIM_OCInitTypeDef         TIM_OCInitStructure;
DMA_InitTypeDef           DMA_InitStructure;
uint8_t DummyByte = 0xA5;

			   
/******************************************************************************************************/
/*                                         globale Funktionen                                         */
/******************************************************************************************************/

/**
  * \brief  DMAVarInit
  *
  * Initialisiert alle Variablen 
  *
  * \param	parameter   none
  * \return	            none
  *
  */

void DMAVarInit (void)
{
	u8DoubleBufferDSPControl = 0;
  	u8DoubleBufferCommunicationControl = 0;
 	u16CountOfModifideDatasBuffer1 = BUFFER_WIDE;
 	u16CountOfModifideDatasBuffer2 = BUFFER_WIDE;
	u32CounterOfDMAStreamedDatas = 0;
}

/*******************************************************************************
* Function Name  : main
* Description    : Main program
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void init_DMA (void)
{
//  /* System Clocks Configuration */
//  RCC_Configuration_DMA();
//       
//  /* NVIC configuration */
//  NVIC_Configuration_DMA();
//
//  /* DMA1 Channel2 configuration ----------------------------------------------*/
//  DMA_DeInit(DMA1_Channel2);
//  DMA_InitStructure.DMA_PeripheralBaseAddr = (u32)TIM1_CCR1_Address;
//  DMA_InitStructure.DMA_MemoryBaseAddr = (u32)SPI_MASTER_DR_Base;
//  DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralDST;
//  DMA_InitStructure.DMA_BufferSize = 1;
//  DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;
//  DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Disable;
//  DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_Byte;
//  DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_Byte;
//  DMA_InitStructure.DMA_Mode = DMA_Mode_Circular;
//  DMA_InitStructure.DMA_Priority = DMA_Priority_High;
//  DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;
//  DMA_Init(DMA1_Channel2, &DMA_InitStructure);
//  /* Enable DMA1 Channel5 */
//  DMA_Cmd(DMA1_Channel2, ENABLE);    
}

/*******************************************************************************
* Function Name  : RCC_Configuration
* Description    : Configures the different system clocks.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RCC_Configuration_DMA(void)
{
  /* RCC system reset(for debug purpose) */
  //RCC_DeInit();

  /* Enable HSE */
  RCC_HSEConfig(RCC_HSE_ON);

  /* Wait till HSE is ready */
  HSEStartUpStatus_DMA = RCC_WaitForHSEStartUp();

  if(HSEStartUpStatus_DMA == SUCCESS)
  {
    /* Enable Prefetch Buffer */
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);

    /* Flash 2 wait state */
    FLASH_SetLatency(FLASH_Latency_2);
 
    /* HCLK = SYSCLK */
    RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  
    /* PCLK2 = HCLK */
    RCC_PCLK2Config(RCC_HCLK_Div1); 

    /* PCLK1 = HCLK/2 */
    RCC_PCLK1Config(RCC_HCLK_Div2);

    /* ADCCLK = PCLK2/8 */
    RCC_ADCCLKConfig(RCC_PCLK2_Div8); 

    /* PLLCLK = 8MHz * 9 = 72 MHz */
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);

    /* Enable PLL */ 
    RCC_PLLCmd(ENABLE);

    /* Wait till PLL is ready */
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET)
    {
    }

    /* Select PLL as system clock source */
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);

    /* Wait till PLL is used as system clock source */
    while(RCC_GetSYSCLKSource() != 0x08)
    {
    }
  }

/* Enable peripheral clocks --------------------------------------------------*/
  /* Enable DMA1 clock */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);
}


/*******************************************************************************
* Function Name  : NVIC_Configuration
* Description    : Configures Vector Table base location.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void NVIC_Configuration_DMA(void)
{
	//Enable DMA1Chanel2 TCI
  NVIC_InitTypeDef NVIC_InitStructure;

  NVIC_PriorityGroupConfig(NVIC_PriorityGroup_1);

  NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel2_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);

  NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel5_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);


#ifdef  VECT_TAB_RAM  
  /* Set the Vector Table base location at 0x20000000 */ 
  NVIC_SetVectorTable(NVIC_VectTab_RAM, 0x0); 
#else  /* VECT_TAB_FLASH  */
  /* Set the Vector Table base location at 0x08000000 */ 
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);   
#endif
}


/**
  * \brief  StartDMATransferToBuffer
  *
  * Startet den DMA Transfer vom SPI Flash in den internen Datenpuffer
  * und initialisiert alle hierfr ntigen Register und Variablen. 
  *
  * \param	parameter   uint16_t u16Titel
  * \return	            none
  *
  */


void StartDMATransferToBuffer (uint16_t u16Titel)
{
	/**
	Test wie man Daten ber die DMA Schnittstelle vom Mem an die SPI sendet
	DMA SPI1 TX -> DMA1 CH3
	kann nur 16 Bit sein wenn SPI auch 16 bit empfangen kann !!!
	hoffentlich!
	**/
	DMA_InitTypeDef DMA_InitStructure;
	uint8_t rw_workbyte[] = { 0x55 };
	uint32_t u32Laufvar;

	float tCPU		 = 1.0/TIMFREQUENZ;
	float tSampling	 = 1.0/get_SampleRate( u16Titel );
	
	fQuantisationTime = (uint16_t)(tSampling/tCPU);

	fSkalierungsfaktorXAchse = fQuantisationTime/(pow(2,get_BitsPerSample(u16Titel)));

	for(u32Laufvar = 0 ; u32Laufvar < (BUFFER_WIDE*2) ; u32Laufvar++) 
	{
		u16MasterOutBuffer[u32Laufvar] = fQuantisationTime/2;
	}

	//Alle Puffer gelten als leer
	u8DoubleBufferCommunicationControl = 0;

  	DMA_DeInit(DMA1_Channel3);

  	RCC_Configuration_DMA();
  	RCC_Configuration_PWM();
  	NVIC_Configuration_DMA();
		
	u16BytesToTransferPerDMACycle = BUFFER_WIDE * get_BlockAlign(u16Titel);

	//Neue Adresse im Flash da immer ein Byte bersprungen wurde
	u32JumpAdressDuringBufferChanging = get_AudioStartAdress(u16Titel);
    PrepareFlashToRead(u32JumpAdressDuringBufferChanging);

	DMA_DeInit(DMA1_Channel3);

	DMA_Cmd(DMA1_Channel2, DISABLE);
	DMA_Cmd(DMA1_Channel3, DISABLE);

	DMA_InitStructure.DMA_PeripheralBaseAddr = (uint32_t)&(SPI1->DR);
	DMA_InitStructure.DMA_MemoryBaseAddr = (uint32_t)&rw_workbyte[0];
	DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralDST;

	DMA_InitStructure.DMA_BufferSize = u16BytesToTransferPerDMACycle;//(uint32_t)(get_AudioEndAdress(u16Titel)-get_AudioStartAdress(u16Titel)); //<-wie viel
	DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;
	DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Disable;
	DMA_InitStructure.DMA_Mode = DMA_Mode_Normal;//DMA_Mode_Circular;
	DMA_InitStructure.DMA_Priority = DMA_Priority_VeryHigh;
	DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;
	DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_Byte;
	DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_Byte;	

	
	//TX Chanel um Clock zu erzwingen	
	DMA_Init(DMA1_Channel3, &DMA_InitStructure);
	//---------------------------------9---------------------

	DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralSRC;
	DMA_InitStructure.DMA_PeripheralBaseAddr = (uint32_t)&(SPI1->DR);
	
	DMA_InitStructure.DMA_MemoryBaseAddr = (uint32_t)&(u16DoubleBuffer1[0]);
	
	DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;//DMA_MemoryInc_Enable;
	 
	DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord;
	DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_Byte;//DMA_MemoryDataSize_HalfWord;	
	//DMA_InitStructure.DMA_BufferSize = (uint32_t)0x4; //<-wie viel
	DMA_InitStructure.DMA_Mode = DMA_Mode_Normal;
	//RX Chanel um zu empfangen
	DMA_Init(DMA1_Channel2, &DMA_InitStructure);
	//PufferWahl();

	DMA_ITConfig(DMA1_Channel2, DMA_IT_TC, ENABLE);
	//------------------------------------------------------
	SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Rx | SPI_I2S_DMAReq_Tx, ENABLE);
		
	DMA_Cmd(DMA1_Channel2, ENABLE);
	DMA_Cmd(DMA1_Channel3, ENABLE);

	InitPWM((uint16_t)fQuantisationTime,0,0);

	StartDMATransferToSpeaker(BUFFER_WIDE);
	
	 //Stimmt das? nachprfen
//	while (DMA_GetFlagStatus(DMA1_FLAG_TC2) == RESET) { ; }

//	SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Rx | SPI_I2S_DMAReq_Tx, DISABLE);
//	DMA_Cmd(DMA1_Channel2, DISABLE);
//	DMA_Cmd(DMA1_Channel3, DISABLE);
}

/**
  * \brief  StartDMATransferToSpeaker
  *
  * Startet den DMA Transfer vom internen Datenpuffer an den PWM Timer
  * und initialisiert alle hierfr ntigen Register und Variablen. 
  * bergeben wird die lnge des Datenpuffers
  *
  * \param	parameter   uint16_t u16Stepwide
  * \return	            none
  *
  */

void StartDMATransferToSpeaker (uint16_t u16Stepwide)
{
	DMA_InitTypeDef DMA_InitStructure; 

  /* DMA1 Channel5 Config */
  DMA_DeInit(DMA1_Channel5);

  DMA_InitStructure.DMA_PeripheralBaseAddr = (uint32_t)&(TIM1->CCR1);
  DMA_InitStructure.DMA_MemoryBaseAddr = (uint32_t)&(u16MasterOutBuffer[0]);
  DMA_InitStructure.DMA_BufferSize = u16Stepwide*2; //Kommt mal rein
  DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralDST;
  DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;
  DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;
  DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord;
  DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_HalfWord;
  DMA_InitStructure.DMA_Mode = DMA_Mode_Circular;
  DMA_InitStructure.DMA_Priority = DMA_Priority_VeryHigh;
  DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;

  DMA_Init(DMA1_Channel5, &DMA_InitStructure);

  //Erste starten wen der Erste Puffer voll ist sonst gibt es noch nichts zum bertragen
  //while(DOUBLE_BUFFER_1_EMPTY() == FALSE){;}

  DMA_ITConfig(DMA1_Channel5, DMA_IT_TC, ENABLE);
  DMA_ITConfig(DMA1_Channel5, DMA_IT_HT, ENABLE);

  /* DMA1 Channel5 enable */
  //Hier wieder anschalten nur zum debuggen aus
  DMA_Cmd(DMA1_Channel5, ENABLE);		
}

/**
  * \brief  StopDMATransferToSpeaker
  *
  * Deaktiviert den DMA Verkehr zum Lautsprefcher
  *
  * \param	parameter   none
  * \return	            none
  *
  */

void StopDMATransferToSpeaker (void)
{
	DMA_DeInit(DMA1_Channel5);
	DMA_Cmd(DMA1_Channel5, DISABLE);	
}

/**
  * \brief  DMA1_Channel2_IRQHandler
  *
  * Managed den DMA Transfer zwischen SPI und internem Speicher
  *
  * \param	parameter   none
  * \return	            none
  *
  */

void DMA1_Channel2_IRQHandler (void)
{
	uint16_t u16Walker;
	 int16_t s16SkalierungsfaktorYAchse;
	uint32_t u32Temp;

	DMA_Cmd(DMA1_Channel3, DISABLE);
	DMA_Cmd(DMA1_Channel2, DISABLE);	
	SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Rx | SPI_I2S_DMAReq_Tx, DISABLE);





	if(DMA1_Channel2->CMAR == (uint32_t)&(u16DoubleBuffer1[0]))
	{
			 //-------------------------------
			 //Setze Puffer 1 Voll
			 //Verarbeite Messwerte
			 //Gebe Puffer 1 frei fr Speakertransfer
			 //-------------------------------
				DOUBLE_BUFFER_1_SET_FULL();
		
			if(DOUBLE_BUFFER_1_NOT_READY())
			{
				s16SkalierungsfaktorYAchse = fQuantisationTime/2;//(pow(2,u16MomentanBitsPerSample)/2);
		
				for(u16Walker = 0 ; u16Walker < (u16BytesToTransferPerDMACycle/2) ; u16Walker++)
				{
					u16DoubleBuffer1[u16Walker] = ((u16DoubleBuffer1[u16Walker]*fSkalierungsfaktorXAchse)+s16SkalierungsfaktorYAchse);
				}
			}
		
				DOUBLE_BUFFER_1_SET_READY();
	
		if(DOUBLE_BUFFER_2_EMPTY())
		{
		 //-------------------------------
		 //Flash auf nchsten Transfer vorbereiten
		 //-------------------------------
		 u32Temp = (uint32_t)u16BytesToTransferPerDMACycle;
		 u32JumpAdressDuringBufferChanging = u32JumpAdressDuringBufferChanging + u32Temp;
		 PrepareFlashToRead(u32JumpAdressDuringBufferChanging);
		 //-------------------------------
		 //Puffer 2 ist demnach gerade Leer
		 //Auerdem sind noch alter Werte drin also nicht bereit
		 //-------------------------------
			DOUBLE_BUFFER_2_SET_EMPTY();
			DOUBLE_BUFFER_2_SET_NOT_READY();
		 //-------------------------------
		 //Reinit der Laufweite
		 //-------------------------------
		 	DMA1_Channel2->CNDTR = u16BytesToTransferPerDMACycle;
			DMA1_Channel3->CNDTR = u16BytesToTransferPerDMACycle;
		 //-------------------------------
		 //Transfer von SPI zu Puffer 2 initialisieren 
		 //um diesen mit neuen Daten zu fllen
		 //-------------------------------
			DMA1_Channel2->CMAR = (uint32_t)&(u16DoubleBuffer2[0]);	
		//-------------------------------
		 //Interruptflags lschen
		 //-------------------------------
		 DMA1->IFCR |= (DMA_IFCR_CTCIF2 | DMA_IFCR_CHTIF2);
		 //-------------------------------
		 //Datenbertragung SPI -> Buf2 starten
		 //-------------------------------		
			SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Rx | SPI_I2S_DMAReq_Tx, ENABLE);
			DMA_Cmd(DMA1_Channel2, ENABLE);
			DMA_Cmd(DMA1_Channel3, ENABLE);
		}
	}
	else if(DMA1_Channel2->CMAR == (uint32_t)&(u16DoubleBuffer2[0]))
	{
			//-------------------------------
	 //Setze Puffer 2 Voll
	 //Verarbeite Messwerte
	 //Gebe Puffer 2 frei fr Speakertransfer
	 //-------------------------------
		DOUBLE_BUFFER_2_SET_FULL();

	if(DOUBLE_BUFFER_2_NOT_READY())
	{

		s16SkalierungsfaktorYAchse = fQuantisationTime/2;//(pow(2,u16MomentanBitsPerSample)/2);

		for(u16Walker = 0 ; u16Walker < (u16BytesToTransferPerDMACycle/2) ; u16Walker++)
		{
			u16DoubleBuffer2[u16Walker] = ((u16DoubleBuffer2[u16Walker]*fSkalierungsfaktorXAchse)+s16SkalierungsfaktorYAchse);
		}
	}

		DOUBLE_BUFFER_2_SET_READY();
	 if(DOUBLE_BUFFER_1_EMPTY())
	 {	
	 //-------------------------------
	 //Flash auf nchsten Transfer vorbereiten
	 //-------------------------------
	 u32Temp = (uint32_t)u16BytesToTransferPerDMACycle;
	 u32JumpAdressDuringBufferChanging = u32JumpAdressDuringBufferChanging + u32Temp;
	 PrepareFlashToRead(u32JumpAdressDuringBufferChanging);	
	 //-------------------------------
	 //Puffer 1 ist demnach gerade Leer
	 //Auerdem sind noch alter Werte drin also nicht bereit
	 //-------------------------------
		DOUBLE_BUFFER_1_SET_EMPTY();
		DOUBLE_BUFFER_1_SET_NOT_READY();
	 //-------------------------------
	 //Reinit der Laufweite
	 //-------------------------------
	 	DMA1_Channel2->CNDTR = u16BytesToTransferPerDMACycle;
		DMA1_Channel3->CNDTR = u16BytesToTransferPerDMACycle;
	 //-------------------------------
	 //Transfer von SPI zu Puffer 1 initialisieren 
	 //um diesen mit neuen Daten zu fllen
	 //-------------------------------
		DMA1_Channel2->CMAR = (uint32_t)&(u16DoubleBuffer1[0]);	
	 //-------------------------------
	 //Interruptflags lschen
	 //-------------------------------
	    DMA1->IFCR |= (DMA_IFCR_CTCIF2 | DMA_IFCR_CHTIF2);
	 //-------------------------------
	 //Datenbertragung SPI -> Buf1 starten
	 //-------------------------------		
		SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Rx | SPI_I2S_DMAReq_Tx, ENABLE);
		DMA_Cmd(DMA1_Channel2, ENABLE);
		DMA_Cmd(DMA1_Channel3, ENABLE);
		}
	}	

	if(u32CounterOfDMAStreamedDatas == 0)
	{
		u32CounterOfDMAStreamedDatas = 1;
		TIM_DMACmd(TIM1, TIM_DMA_Update, ENABLE);
  		TIM_Cmd(TIM1, ENABLE);		
		DMA_Cmd(DMA1_Channel5, ENABLE);
	}
}

/**
  * \brief  DMA1_Channel5_IRQHandler
  *
  * Managed den DMA Transfer zwischen internem Speicher und dem PWM Timer
  *
  * \param	parameter   none
  * \return	            none
  *
  */

void DMA1_Channel5_IRQHandler (void)
{
 uint16_t Laufvar;

  //DMA_ISR_TCIF1	 Transfer Complet
  //DMA_ISR_HTIF1 	 Half Transfer
	if(DMA_GetITStatus(DMA1_IT_HT5))
	{
		/*
		Half Buffer Transferd Flag wird gesetzt wenn halber Puffer bertragen
		D.h. obere hlfte wurde transfertiert kann also berschrieben werden
		*/	
		for(Laufvar = 0 ; Laufvar < (u16BytesToTransferPerDMACycle/2); Laufvar++)
		{
			u16MasterOutBuffer[Laufvar] = u16DoubleBuffer1[Laufvar];
		}
		DOUBLE_BUFFER_1_SET_READY();
		DOUBLE_BUFFER_1_SET_EMPTY();
		DMA1->IFCR |= DMA_IFCR_CHTIF5;
			
	}
	else if(DMA_GetITStatus(DMA1_IT_TC5))
	{
		for(Laufvar = 0 ; Laufvar < (u16BytesToTransferPerDMACycle/2); Laufvar++)
		{
			u16MasterOutBuffer[Laufvar+(u16BytesToTransferPerDMACycle/2)] = u16DoubleBuffer2[Laufvar];		
		}
		DOUBLE_BUFFER_2_SET_READY();
		DOUBLE_BUFFER_2_SET_EMPTY();
		DMA1->IFCR |= DMA_IFCR_CTCIF5;
	}	
}


#pragma O3

#undef __DMA_USER_C


