#define __HW_CONFIG_C

/******************** (C) COPYRIGHT 2010 STMicroelectronics ********************
* File Name          : hw_config.c
* Author             : MCD Application Team
* Version            : V3.1.1
* Date               : 04/07/2010
* Description        : Hardware Configuration & Setup
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/


/* Includes ------------------------------------------------------------------*/
#include "global.h"
#include "stm32f10x_it.h"
#include "usb_lib.h"
#include "usb_prop.h"
#include "usb_desc.h"
#include "hw_config.h"
#include "platform_config.h"
#include "usb_pwr.h"
#include "internal_flash.h"
#include "math.h"
#include "stm32_eval.h"
#include "spi_flash.h"
#include "menue.h"
#include "usb_endp.h"

#pragma O0

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
ErrorStatus HSEStartUpStatus;
USART_InitTypeDef USART_InitStructure;

/* Extern variables ----------------------------------------------------------*/
extern sLINE_CODING 	linecoding;


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * \brief  VarInit_HW_Config
  *
  * Diese Funktrion initialisiert alle Variablen die
  * das Management des Systems betreffen
  * \param	parameter   none
  * \return	            none
  *
  */
void VarInit_HW_Config (void)
{
	u16Counter_Datas_From_PC0 = 0x0000;
	u16Counter_Datas_From_PC1 = 0x0000;
	u64Audio_Total_Byte_Counter = 0;
	u32Audio_Byte_Counter_Max_Value = 0xFFFFFFFF;
	u16Areas_Needed_For_File = 0x0000;
	u16Titel_Counter = 0x0001; 
	u8UserTitelNumber = 0x00;
	u8StateMaschine = COMMUNICATION_DETECTED;
}
/*******************************************************************************
* Function Name  : Set_System
* Description    : Configures Main system clocks & power
* Input          : None.
* Return         : None.
*******************************************************************************/
void Set_System(void)
{
#ifndef USE_STM3210C_EVAL
  GPIO_InitTypeDef GPIO_InitStructure;
#endif /* USE_STM3210C_EVAL */

  /* SYSCLK, HCLK, PCLK2 and PCLK1 configuration -----------------------------*/   
  /* RCC system reset(for debug purpose) */
  RCC_DeInit();

  /* Enable HSE */
  RCC_HSEConfig(RCC_HSE_ON);

  /* Wait till HSE is ready */
  HSEStartUpStatus = RCC_WaitForHSEStartUp();

  if (HSEStartUpStatus == SUCCESS)
  {
    /* Enable Prefetch Buffer */
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);

    /* Flash 2 wait state */
    FLASH_SetLatency(FLASH_Latency_2);
 
    /* HCLK = SYSCLK */
    RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  
    /* PCLK2 = HCLK */
    RCC_PCLK2Config(RCC_HCLK_Div1); 

    /* PCLK1 = HCLK/2 */
    RCC_PCLK1Config(RCC_HCLK_Div2);

#ifdef STM32F10X_CL
    /* Configure PLLs *********************************************************/
    /* PLL2 configuration: PLL2CLK = (HSE / 5) * 8 = 40 MHz */
    RCC_PREDIV2Config(RCC_PREDIV2_Div5);
    RCC_PLL2Config(RCC_PLL2Mul_8);

    /* Enable PLL2 */
    RCC_PLL2Cmd(ENABLE);

    /* Wait till PLL2 is ready */
    while (RCC_GetFlagStatus(RCC_FLAG_PLL2RDY) == RESET)
    {}

    /* PLL configuration: PLLCLK = (PLL2 / 5) * 9 = 72 MHz */ 
    RCC_PREDIV1Config(RCC_PREDIV1_Source_PLL2, RCC_PREDIV1_Div5);
    RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_9);
#else
    /* PLLCLK = 8MHz * 9 = 72 MHz */
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);
#endif

    /* Enable PLL */ 
    RCC_PLLCmd(ENABLE);

    /* Wait till PLL is ready */
    while (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET)
    {
    }

    /* Select PLL as system clock source */
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);

    /* Wait till PLL is used as system clock source */
    while(RCC_GetSYSCLKSource() != 0x08)
    {
    }
  }
  else
  { /* If HSE fails to start-up, the application will have wrong clock configuration.
       User can add here some code to deal with this error */    

    /* Go to infinite loop */
    while (1)
    {
    }
  }

#ifndef USE_STM3210C_EVAL
  /* Enable USB_DISCONNECT GPIO clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIO_DISCONNECT, ENABLE);

  /* Configure USB pull-up pin */
  GPIO_InitStructure.GPIO_Pin = USB_DISCONNECT_PIN;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_OD;
  GPIO_Init(USB_DISCONNECT, &GPIO_InitStructure);
#endif /* USE_STM3210C_EVAL */
}

/*******************************************************************************
* Function Name  : Set_USBClock
* Description    : Configures USB Clock input (48MHz)
* Input          : None.
* Return         : None.
*******************************************************************************/
void Set_USBClock(void)
{
#ifdef STM32F10X_CL
  /* Select USBCLK source */
  RCC_OTGFSCLKConfig(RCC_OTGFSCLKSource_PLLVCO_Div3);

  /* Enable the USB clock */ 
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_OTG_FS, ENABLE) ;
#else 
  /* Select USBCLK source */
  RCC_USBCLKConfig(RCC_USBCLKSource_PLLCLK_1Div5);
  
  /* Enable the USB clock */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_USB, ENABLE);
#endif /* STM32F10X_CL */
}

/*******************************************************************************
* Function Name  : Enter_LowPowerMode
* Description    : Power-off system clocks and power while entering suspend mode
* Input          : None.
* Return         : None.
*******************************************************************************/
void Enter_LowPowerMode(void)
{
  /* Set the device state to suspend */
  bDeviceState = SUSPENDED;
}

/*******************************************************************************
* Function Name  : Leave_LowPowerMode
* Description    : Restores system clocks and power while exiting suspend mode
* Input          : None.
* Return         : None.
*******************************************************************************/
void Leave_LowPowerMode(void)
{
  DEVICE_INFO *pInfo = &Device_Info;

  /* Set the device state to the correct state */
  if (pInfo->Current_Configuration != 0)
  {
    /* Device configured */
    bDeviceState = CONFIGURED;
  }
  else
  {
    bDeviceState = ATTACHED;
  }
}

/*******************************************************************************
* Function Name  : USB_Interrupts_Config
* Description    : Configures the USB interrupts
* Input          : None.
* Return         : None.
*******************************************************************************/
void USB_Interrupts_Config(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;

  NVIC_PriorityGroupConfig(NVIC_PriorityGroup_1);

#ifdef STM32F10X_CL 
  /* Enable the USB Interrupts */
  NVIC_InitStructure.NVIC_IRQChannel = OTG_FS_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);
#else
  NVIC_InitStructure.NVIC_IRQChannel = USB_LP_CAN1_RX0_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);
#endif /* STM32F10X_CL */

  /* Enable USART Interrupt */
  NVIC_InitStructure.NVIC_IRQChannel = EVAL_COM1_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
  NVIC_Init(&NVIC_InitStructure);
}

/*******************************************************************************
* Function Name  : USB_Cable_Config
* Description    : Software Connection/Disconnection of USB Cable
* Input          : None.
* Return         : Status
*******************************************************************************/
void USB_Cable_Config (FunctionalState NewState)
{
#ifdef USE_STM3210C_EVAL  
  if (NewState != DISABLE)
  {
    USB_DevConnect();
  }
  else
  {
    USB_DevDisconnect();
  }
#else /* USE_STM3210B_EVAL or USE_STM3210E_EVAL */
  if (NewState != DISABLE)
  {
    GPIO_ResetBits(USB_DISCONNECT, USB_DISCONNECT_PIN);
  }
  else
  {
    GPIO_SetBits(USB_DISCONNECT, USB_DISCONNECT_PIN);
  }
#endif /* USE_STM3210C_EVAL */
}

/*******************************************************************************
* Function Name  :  USART_Config_Default.
* Description    :  configure the EVAL_COM1 with default values.
* Input          :  None.
* Return         :  None.
*******************************************************************************/
void USART_Config_Default(void)
{
  /* EVAL_COM1 default configuration */
  /* EVAL_COM1 configured as follow:
        - BaudRate = 9600 baud  
        - Word Length = 8 Bits
        - One Stop Bit
        - Parity Odd
        - Hardware flow control desabled
        - Receive and transmit enabled
  */
  USART_InitStructure.USART_BaudRate = 9600;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_Odd;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;

  /* Configure and enable the USART */
  STM_EVAL_COMInit(COM1, &USART_InitStructure);

  /* Enable the USART Receive interrupt */
  USART_ITConfig(EVAL_COM1, USART_IT_RXNE, ENABLE);
}

/*******************************************************************************
* Function Name  :  USART_Config.
* Description    :  Configure the EVAL_COM1 according to the linecoding structure.
* Input          :  None.
* Return         :  Configuration status
                    TRUE : configuration done with success
                    FALSE : configuration aborted.
*******************************************************************************/
bool USART_Config(void)
{

  /* set the Stop bit*/
  switch (linecoding.format)
  {
    case 0:
      USART_InitStructure.USART_StopBits = USART_StopBits_1;
      break;
    case 1:
      USART_InitStructure.USART_StopBits = USART_StopBits_1_5;
      break;
    case 2:
      USART_InitStructure.USART_StopBits = USART_StopBits_2;
      break;
    default :
    {
      USART_Config_Default();
      return (FALSE);
    }
  }

  /* set the parity bit*/
  switch (linecoding.paritytype)
  {
    case 0:
      USART_InitStructure.USART_Parity = USART_Parity_No;
      break;
    case 1:
      USART_InitStructure.USART_Parity = USART_Parity_Even;
      break;
    case 2:
      USART_InitStructure.USART_Parity = USART_Parity_Odd;
      break;
    default :
    {
      USART_Config_Default();
      return (FALSE);
    }
  }

  /*set the data type : only 8bits and 9bits is supported */
  switch (linecoding.datatype)
  {
    case 0x07:
      /* With this configuration a parity (Even or Odd) should be set */
      USART_InitStructure.USART_WordLength = USART_WordLength_8b;
      break;
    case 0x08:
      if (USART_InitStructure.USART_Parity == USART_Parity_No)
      {
        USART_InitStructure.USART_WordLength = USART_WordLength_8b;
      }
      else 
      {
        USART_InitStructure.USART_WordLength = USART_WordLength_9b;
      }
      
      break;
    default :
    {
      USART_Config_Default();
      return (FALSE);
    }
  }

  USART_InitStructure.USART_BaudRate = linecoding.bitrate;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
 
  /* Configure and enable the USART */
  STM_EVAL_COMInit(COM1, &USART_InitStructure);

  return (TRUE);
}

/*******************************************************************************
* Function# Name  : USB_To_USART_Buffer.
* Description    : send the received data from USB to the UART 0.
* Input          : data_buffer: data address.
                   Nb_bytes: number of bytes to send.
* Return         : none.
*******************************************************************************/

/**
  * \brief  USB_To_User_Buffer_Send_Data
  *
  * Diese Funktion Managed ankommende Daten und verteilt diese
  * in die jeweils aktiven Puffer
  * Hierzu wird der Puffer und die Anzahl der empfangenen Daten bergeben
  * \param	parameter   uint8_t* data_buffer, uint8_t Nb_bytes
  * \return	            none
  *
  */

void USB_To_User_Buffer_Send_Data(uint8_t* data_buffer, uint8_t Nb_bytes)
{
  if(   u8StateMaschine != EXCEPT_SUBCOMMANDS  
     && u8StateMaschine != RECIVE_NEW_AUDIOFILES 
	 && u8StateMaschine !=  GET_USER_TITEL_WISH 
	 && u8StateMaschine !=  EXCEPT_TESTINFOS)  //alles auer Kommandos und empfang
  {
  	u8User_Commands_From_PC = u8Buffer_Out[0];
  }

  else if(u8StateMaschine == EXCEPT_SUBCOMMANDS) //Kommandos
  {
  	u8User_Sub_Commands_From_PC = u8Buffer_Out[0];	
  }

  else if(u8StateMaschine == GET_USER_TITEL_WISH)
  {
  	u8UserTitelNumber = u8Buffer_Out[0];
	u8StateMaschine = COMMUNICATION_DETECTED;
  }

  else if(u8StateMaschine == EXCEPT_TESTINFOS)
  {
  	u8User_Sub_Commands_For_Testtone = u8Buffer_Out[0];	
  }
}

/**
  * \brief  SaveRecivedDatas
  *
  * Diese Funktion Managed ankommende Audiodaten.
  * Hier wird der Header separiert und zur Sicherheit sowohl im externen Flash
  * als auch im internen Speicher des Controllers gespeichert
  * \param	parameter   none
  * \return	            none
  *
  */

void SaveRecivedDatas(void)
{
	//Problem erstes Interrupt verhaut neues Byte!!!
  //Ringpuffer oder zwei Puffer einsetzen !!! <- besseres Model da einfacher inn vorhandene sw einzubinden 
  //switch case um zwischen zwei puffern wechseln
  //im groen puffer sind die Daten vorhanden im kleinen wird
  //das erste Datum berschrieben
  //dann drften auch keine laufzeitunterschiede mehr auftreten
  //berlegen ob eigene routine fr datenempfang
  //evtl wegen neuem counter damit auch der letzte 
  //datensatz verarbeitet werden kann
		if(u64Audio_Total_Byte_Counter >= u32Audio_Byte_Counter_Max_Value && u64Audio_Total_Byte_Counter > 256)
		{
			struct Textinfo *temp;
			//Kopiere letzte Paar Byte rber
			uint8_t Rest = u64Audio_Total_Byte_Counter - u16Areas_Needed_For_File*BUFFER_VALUE;
			if(u8BufferControl == Buffer0)
			{
				SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC0 , (u16Areas_Needed_For_File*BUFFER_VALUE) ,Rest); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
			}
			else if(u8BufferControl == Buffer1)
			{
				SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC1 , (u16Areas_Needed_For_File*BUFFER_VALUE) ,Rest); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
			}
		
			temp = Text_to_Array("\n\r\n\r File empfangen\n\r\n\r");
			User_Buffer_to_USB_Send_Data(&(*temp).Text[0], (*temp).size);

			
			set_EEPROMNumberOfTitels((u16Titel_Counter));
			u8User_Commands_From_PC = ALL_DONE;
  			u8User_Sub_Commands_From_PC = ALL_DONE;
  			u8StateMaschine = START_COMMUNICATION;
			u16Areas_Needed_For_File = 0x00;
			u64Audio_Total_Byte_Counter = 0;
			u32Audio_Byte_Counter_Max_Value = 0xFFFFFFFF;
			u8BufferControl = Buffer0;
  			u8BufferFilled  = 0x00;
  			u8EndOfFile = 0x00;
			return;
			}
			 
			if(u16Areas_Needed_For_File == FIRST_AREA)
			{
				/*First Area Contains some informations about file
				* 	Endian		Offset		Fild Name			Fild Size		Description		
				* 	big			   0		ChunkID			    	4			contains "RIFF"	(0x52494646 big-endian form
				*	little		   4		ChunkSize				4			Size from her to end (36+Size2)
				*	big			   8		Format					4			contains "WAVE" (0x57415645 big-endian form)
				*	big			  12		Subchunk1ID				4			contains "fmt" (0x666d7420 big-endian form
				*	little		  16		Subchunk1Size			4			0xF by PCM
				*	little		  20		AudioFormat				2			PCM = 0x01 all others are Compressed
				*	little		  22		NumChannels				2			0x01 Mono 0x02 Stereo
				*	little		  24		SampleRate				4			8000, 44100, etc.
				*	little		  28		ByteRate				4		    == SampleRate * NumChannels * BitsPerSample/8
				*	little		  32		BlockAlign				2			== NumChannels * BitsPerSample/8
				*	little		  34		BitsPerSample			2			8 bits = 8, 16 bits = 16, etc.
				*	big			  36		Subchunk2ID				4			contains "data"	 (0x64617461 big-endian form)
				*	little		  40		SubchunkSize			4			== NumSamples * NumChannels * BitsPerSample/8
				*	little		  44	   	Datas		   	  Subchunk2Size
				*/ 
				if(u8BufferFilled == Buffer0)
				{	
					StrucktSetCurrent((u16Titel_Counter-1), &u8User_Buffer_Datas_From_PC0[0]);		
				}
				else if(u8BufferFilled == Buffer1)
				{	
					StrucktSetCurrent((u16Titel_Counter-1), &u8User_Buffer_Datas_From_PC1[1]);
				}
				u32Audio_Byte_Counter_Max_Value = (get_EndAdress((u16Titel_Counter-1))) - get_StartAdress((u16Titel_Counter-1));
				
				CopyStrucktToEEPROM((u16Titel_Counter-1));
			}
			
			if(u8BufferFilled == Buffer0)
			{	
				if(u16Titel_Counter <= 0x01)
				{
					SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC0 , (u16Areas_Needed_For_File*BUFFER_VALUE) ,BUFFER_VALUE); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
				}
				else
				{
					//Ermitteln der Adresse der nchsten freien Page
					uint32_t u32Offset = (get_EndAdress(u16Titel_Counter-2))+1;					
					SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC0 , u32Offset+(u16Areas_Needed_For_File*BUFFER_VALUE) ,BUFFER_VALUE); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
				}
				u8BufferFilled &= ~(Buffer0);
			}
			else if(u8BufferFilled == Buffer1)
			{
				if(u16Titel_Counter <= 0x01)
				{	
					SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC1 , (u16Areas_Needed_For_File*BUFFER_VALUE) ,BUFFER_VALUE); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
				}
				else
				{
					//Ermitteln der Adresse der nchsten freien Page
					uint32_t u32Offset = get_EndAdress(u16Titel_Counter-2)+1;
					SPI_FLASH_BufferWrite(u8User_Buffer_Datas_From_PC1 , u32Offset+(u16Areas_Needed_For_File*BUFFER_VALUE) ,BUFFER_VALUE); //Hier fehlt noch das NEW_SONG_OFFSET !!! muss bei der Init der SD berprft werden. Auerdem sollte die Anz der Titel und deren Namn, lnge, etc erscheinen.			
				}

				u8BufferFilled &= ~(Buffer1);
			}	
			u16Areas_Needed_For_File++;
}
/*******************************************************************************
* Function Name  : UART_To_USB_Send_Data.
* Description    : send the received data from UART 0 to USB.
* Input          : None.
* Return         : none.
*******************************************************************************/
void User_Buffer_to_USB_Send_Data(uint8_t* data_buffer, uint8_t Nb_bytes)
{
	uint32_t i;

	for (i = 0; i < Nb_bytes; i++)
  	{
    	buffer_in[count_in] = (*(data_buffer + i));
		count_in++;
  	}

  /* Write the data to the USB endpoint */
  USB_SIL_Write(EP1_IN, buffer_in, count_in);
  
#ifndef STM32F10X_CL
  SetEPTxValid(ENDP1);

  for( ; count_in != 0x00 ; )
  {
  	__NOP();
  }	  

#endif /* STM32F10X_CL */
}

/*******************************************************************************
* Function Name  : Get_SerialNum.
* Description    : Create the serial number string descriptor.
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void Get_SerialNum(void)
{
  uint32_t Device_Serial0, Device_Serial1, Device_Serial2;

  Device_Serial0 = *(__IO uint32_t*)(0x1FFFF7E8);
  Device_Serial1 = *(__IO uint32_t*)(0x1FFFF7EC);
  Device_Serial2 = *(__IO uint32_t*)(0x1FFFF7F0);

  if (Device_Serial0 != 0)
  {
    Virtual_Com_Port_StringSerial[2] = (uint8_t)(Device_Serial0 & 0x000000FF);
    Virtual_Com_Port_StringSerial[4] = (uint8_t)((Device_Serial0 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[6] = (uint8_t)((Device_Serial0 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[8] = (uint8_t)((Device_Serial0 & 0xFF000000) >> 24);

    Virtual_Com_Port_StringSerial[10] = (uint8_t)(Device_Serial1 & 0x000000FF);
    Virtual_Com_Port_StringSerial[12] = (uint8_t)((Device_Serial1 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[14] = (uint8_t)((Device_Serial1 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[16] = (uint8_t)((Device_Serial1 & 0xFF000000) >> 24);

    Virtual_Com_Port_StringSerial[18] = (uint8_t)(Device_Serial2 & 0x000000FF);
    Virtual_Com_Port_StringSerial[20] = (uint8_t)((Device_Serial2 & 0x0000FF00) >> 8);
    Virtual_Com_Port_StringSerial[22] = (uint8_t)((Device_Serial2 & 0x00FF0000) >> 16);
    Virtual_Com_Port_StringSerial[24] = (uint8_t)((Device_Serial2 & 0xFF000000) >> 24);
  }
}

/******************* (C) COPYRIGHT 2010 STMicroelectronics *****END OF FILE****/

#undef __HW_CONFIG_C
