#define __INTERNAL_FLASH_C

/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : spi_flash.c
* Author             : MCD Application Team
* Version            : V1.1
* Date               : 11/26/2007
* Description        : This file provides a set of functions needed to manage the
*                      communication between SPI peripheral and SPI M25P64 FLASH.
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "global.h"
#include "stm32f10x_flash.h" 
#include "stm32f10x.h"
#include "eeprom.h"
#include "internal_flash.h"

#define OVERHEAD_OFF
#define KOPIE_OFF
#define CLEAR_OFF

#pragma O3

 /**
  * \brief  set_ChunkID
  *
  * Diese Funktion speichert die ChunkID in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_ChunkID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].ChunkID = 0;
	Titels[Number].ChunkID |= (uint32_t)Byte1;
	Titels[Number].ChunkID = (Titels[Number].ChunkID << 8);
	Titels[Number].ChunkID |= (uint32_t)Byte2;
	Titels[Number].ChunkID = (Titels[Number].ChunkID << 8);
	Titels[Number].ChunkID |= (uint32_t)Byte3;
	Titels[Number].ChunkID = (Titels[Number].ChunkID << 8);
	Titels[Number].ChunkID |= (uint32_t)Byte4;	  
}

 /**
  * \brief  get_ChunkID
  *
  * Diese Funktion gibt den Wert der ChunkID zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            ChunkID from Titel
  *
  */

uint32_t get_ChunkID (uint8_t Number)
{
	return Titels[Number].ChunkID;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_ChunkSize
  *
  * Diese Funktion speichert die ChunkSize in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_ChunkSize (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].ChunkSize = 0;
	Titels[Number].ChunkSize |= (uint32_t)Byte4;
	Titels[Number].ChunkSize = (Titels[Number].ChunkSize << 8);
	Titels[Number].ChunkSize |= (uint32_t)Byte3;
	Titels[Number].ChunkSize = (Titels[Number].ChunkSize << 8);
	Titels[Number].ChunkSize |= (uint32_t)Byte2;
	Titels[Number].ChunkSize = (Titels[Number].ChunkSize << 8);
	Titels[Number].ChunkSize |= (uint32_t)Byte1;	  
}

 /**
  * \brief  get_ChunkSize
  *
  * Diese Funktion gibt den Wert der ChunkSize zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            ChunkSize from Titel
  *
  */

uint32_t get_ChunkSize (uint8_t Number)
{
	return Titels[Number].ChunkSize;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_Format
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_Format (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].Format = 0;
	Titels[Number].Format |= (uint32_t)Byte1;
	Titels[Number].Format = (Titels[Number].Format << 8);
	Titels[Number].Format |= (uint32_t)Byte2;
	Titels[Number].Format = (Titels[Number].Format << 8);
	Titels[Number].Format |= (uint32_t)Byte3;
	Titels[Number].Format = (Titels[Number].Format << 8);
	Titels[Number].Format |= (uint32_t)Byte4;	  
}

 /**
  * \brief  get_Format
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_Format (uint8_t Number)
{
	return Titels[Number].Format;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_Subchunk1ID
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_Subchunk1ID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].Subchunk1ID = 0;
	Titels[Number].Subchunk1ID |= (uint32_t)Byte1;
	Titels[Number].Subchunk1ID = (Titels[Number].Subchunk1ID << 8);
	Titels[Number].Subchunk1ID |= (uint32_t)Byte2;
	Titels[Number].Subchunk1ID = (Titels[Number].Subchunk1ID << 8);
	Titels[Number].Subchunk1ID |= (uint32_t)Byte3;
	Titels[Number].Subchunk1ID = (Titels[Number].Subchunk1ID << 8);
	Titels[Number].Subchunk1ID |= (uint32_t)Byte4;  
}

 /**
  * \brief  get_Subchunk1ID
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_Subchunk1ID (uint8_t Number)
{
	return Titels[Number].Subchunk1ID;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_Subchunk1Size
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_Subchunk1Size (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].Subchunk1Size = 0;
	Titels[Number].Subchunk1Size |= (uint32_t)Byte4;
	Titels[Number].Subchunk1Size = (Titels[Number].Subchunk1Size << 8);
	Titels[Number].Subchunk1Size |= (uint32_t)Byte3;
	Titels[Number].Subchunk1Size = (Titels[Number].Subchunk1Size << 8);
	Titels[Number].Subchunk1Size |= (uint32_t)Byte2;
	Titels[Number].Subchunk1Size = (Titels[Number].Subchunk1Size << 8);
	Titels[Number].Subchunk1Size |= (uint32_t)Byte1;	  
}

 /**
  * \brief  get_Subchunk1Size
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_Subchunk1Size (uint8_t Number)
{
	return Titels[Number].Subchunk1Size;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_AudioFormat
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2
  * \return	            none
  *
  */


void set_AudioFormat (uint8_t Number, uint8_t Byte1, uint8_t Byte2)
{
	Titels[Number].AudioFormat = 0;
	Titels[Number].AudioFormat |= (uint32_t)Byte2;
	Titels[Number].AudioFormat = (Titels[Number].AudioFormat << 8);
	Titels[Number].AudioFormat |= (uint32_t)Byte1;
	  
}

 /**
  * \brief  get_AudioFormat
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint16_t get_AudioFormat (uint8_t Number)
{
	return Titels[Number].AudioFormat;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_NumChannels
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2
  * \return	            none
  *
  */


void set_NumChannels (uint8_t Number, uint8_t Byte1, uint8_t Byte2)
{
	Titels[Number].NumChannels = 0;
	Titels[Number].NumChannels |= (uint32_t)Byte2;
	Titels[Number].NumChannels = (Titels[Number].NumChannels << 8);
	Titels[Number].NumChannels |= (uint32_t)Byte1;
	  
}

 /**
  * \brief  get_NumChannels
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint16_t get_NumChannels (uint8_t Number)
{
	return Titels[Number].NumChannels;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_SampleRate
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_SampleRate (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].SampleRate = 0;
	Titels[Number].SampleRate |= (uint32_t)Byte4;
	Titels[Number].SampleRate = (Titels[Number].SampleRate << 8);
	Titels[Number].SampleRate |= (uint32_t)Byte3;
	Titels[Number].SampleRate = (Titels[Number].SampleRate << 8);
	Titels[Number].SampleRate |= (uint32_t)Byte2;
	Titels[Number].SampleRate = (Titels[Number].SampleRate << 8);
	Titels[Number].SampleRate |= (uint32_t)Byte1;	  
}

 /**
  * \brief  get_SampleRate
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_SampleRate (uint8_t Number)
{
	return Titels[Number].SampleRate;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_ByteRate
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_ByteRate (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].ByteRate = 0;
	Titels[Number].ByteRate |= (uint32_t)Byte4;
	Titels[Number].ByteRate = (Titels[Number].ByteRate << 8);
	Titels[Number].ByteRate |= (uint32_t)Byte3;
	Titels[Number].ByteRate = (Titels[Number].ByteRate << 8);
	Titels[Number].ByteRate |= (uint32_t)Byte2;
	Titels[Number].ByteRate = (Titels[Number].ByteRate << 8);
	Titels[Number].ByteRate |= (uint32_t)Byte1;	  
}

 /**
  * \brief  get_ByteRate
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_ByteRate (uint8_t Number)
{
	return Titels[Number].ByteRate;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_BlockAlign
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2
  * \return	            none
  *
  */


void set_BlockAlign (uint8_t Number, uint8_t Byte1, uint8_t Byte2)
{
	Titels[Number].BlockAlign = 0;
	Titels[Number].BlockAlign |= (uint32_t)Byte2;
	Titels[Number].BlockAlign = (Titels[Number].BlockAlign << 8);
	Titels[Number].BlockAlign |= (uint32_t)Byte1;
	  
}

 /**
  * \brief  get_BlockAlign
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint16_t get_BlockAlign (uint8_t Number)
{
	return Titels[Number].BlockAlign;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_BitsPerSample
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2
  * \return	            none
  *
  */


void set_BitsPerSample (uint8_t Number, uint8_t Byte1, uint8_t Byte2)
{
	Titels[Number].BitsPerSample = 0;
	Titels[Number].BitsPerSample |= (uint32_t)Byte2;
	Titels[Number].BitsPerSample = (Titels[Number].BitsPerSample << 8);
	Titels[Number].BitsPerSample |= (uint32_t)Byte1;
	  
}

 /**
  * \brief  get_BitsPerSample
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint16_t get_BitsPerSample (uint8_t Number)
{
	return Titels[Number].BitsPerSample;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_Subchunk2ID
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_Subchunk2ID (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].Subchunk2ID = 0;
	Titels[Number].Subchunk2ID |= (uint32_t)Byte1;
	Titels[Number].Subchunk2ID = (Titels[Number].Subchunk2ID << 8);
	Titels[Number].Subchunk2ID |= (uint32_t)Byte2;
	Titels[Number].Subchunk2ID = (Titels[Number].Subchunk2ID << 8);
	Titels[Number].Subchunk2ID |= (uint32_t)Byte3;
	Titels[Number].Subchunk2ID = (Titels[Number].Subchunk2ID << 8);
	Titels[Number].Subchunk2ID |= (uint32_t)Byte4;	  
}

 /**
  * \brief  get_Subchunk2ID
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_Subchunk2ID (uint8_t Number)
{
	return Titels[Number].Subchunk2ID;
}


/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_Subchunk2Size
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_Subchunk2Size (uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4)
{
	Titels[Number].Subchunk2Size = 0;
	Titels[Number].Subchunk2Size |= (uint32_t)Byte4;
	Titels[Number].Subchunk2Size = (Titels[Number].Subchunk2Size << 8);
	Titels[Number].Subchunk2Size |= (uint32_t)Byte3;
	Titels[Number].Subchunk2Size = (Titels[Number].Subchunk2Size << 8);
	Titels[Number].Subchunk2Size |= (uint32_t)Byte2;
	Titels[Number].Subchunk2Size = (Titels[Number].Subchunk2Size << 8);
	Titels[Number].Subchunk2Size |= (uint32_t)Byte1;	  
}

 /**
  * \brief  get_SubchunkSize
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_Subchunk2Size (uint8_t Number)
{
	return Titels[Number].Subchunk2Size;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_StartAdress
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_StartAdress (uint8_t Number)
{
	if(Number == 0x00)
	{
		Titels[Number].StartAdress = 0;
	}
	else
	{
		Titels[Number].StartAdress = Titels[Number-1].EndAdress+1;
	}	 
}

/**
  * \brief  get_StartAdress
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_StartAdress (uint8_t Number)
{
	return Titels[Number].StartAdress;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_SEndAdresstartAdress
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_EndAdress (uint8_t Number)
{
	Titels[Number].EndAdress = 0;
	Titels[Number].EndAdress = get_StartAdress(Number) + get_ChunkSize(Number) + 0x08;	 
}

/**
  * \brief  get_EndAdress
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_EndAdress (uint8_t Number)
{
	return Titels[Number].EndAdress;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_AudioStartAdress
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_AudioStartAdress (uint8_t Number)
{
	Titels[Number].AudioStartAdress = 0;
	Titels[Number].AudioStartAdress = get_StartAdress(Number) + 0x2C; //2C = 44 ist offset	 
}

/**
  * \brief  get_AudioStartAdress
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_AudioStartAdress (uint8_t Number)
{
	return Titels[Number].AudioStartAdress;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_AudioEndAdress
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_AudioEndAdress (uint8_t Number)
{
	Titels[Number].AudioEndAdress = 0;
	Titels[Number].AudioEndAdress = get_StartAdress(Number) + 0x2C + get_Subchunk2Size(Number); //2C = 44 ist offset	 
}

/**
  * \brief  get_AudioEndAdress
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_AudioEndAdress (uint8_t Number)
{
	return Titels[Number].AudioEndAdress;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_NumberOfSamples
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */


void set_NumberOfSamples (uint8_t Number)
{
	Titels[Number].NumberOfSamples = 0;
	Titels[Number].NumberOfSamples = (get_Subchunk2Size(Number)*8)/(get_BitsPerSample(Number)*get_NumChannels(Number)); //2C = 44 ist offset	 
}

/**
  * \brief  get_NumberOfSamples
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_NumberOfSamples (uint8_t Number)
{
	return Titels[Number].NumberOfSamples;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_AdressOfLastFile
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */
void set_AdressOfLastFile(uint8_t Number)
{
	Titels[Number].AdressOfLastFile = 0;
	if(Number == 0x00)
	{
		Titels[Number].AdressOfLastFile = 0x00;
	}
	else
	{
		Titels[Number].AdressOfLastFile = get_StartAdress(Number-1);	
	}
}

/**
  * \brief  get_AdressOfLastFile
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_AdressOfLastFile(uint8_t Number)
{
	return Titels[Number].AdressOfLastFile;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_AdressOfNextFile
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   uint8_t Number, uint8_t Byte1, uint8_t Byte2, uint8_t Byte3, uint8_t Byte4
  * \return	            none
  *
  */
void set_AdressOfNextFile(uint8_t Number)
{
	if(Number != 0x00)
	{
		Titels[Number-1].AdressOfNextFile = get_StartAdress(Number);
	}
}

/**
  * \brief  get_AdressOfNextFile
  *
  * Diese Funktion gibt den Wert der Format zurck
  * bergeben werden muss der geforderte Titel
  *
  * \param	parameter   uint8_t Number
  * \return	            Format from Titel
  *
  */

uint32_t get_AdressOfNextFile(uint8_t Number)
{
	return Titels[Number].AdressOfNextFile;
}

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  set_set_all
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   
  * \return	            none
  *
  */

void StrucktSetCurrent (uint8_t Number, uint8_t *pt_Audio_Datas)
{
	set_ChunkID 		(Number, *(pt_Audio_Datas+0), *(pt_Audio_Datas+1), *(pt_Audio_Datas+2), *(pt_Audio_Datas+3));
	set_ChunkSize 		(Number, *(pt_Audio_Datas+4), *(pt_Audio_Datas+5), *(pt_Audio_Datas+6), *(pt_Audio_Datas+7));
	set_Format 			(Number, *(pt_Audio_Datas+8), *(pt_Audio_Datas+9), *(pt_Audio_Datas+10), *(pt_Audio_Datas+11));
	set_Subchunk1ID 	(Number, *(pt_Audio_Datas+12), *(pt_Audio_Datas+13), *(pt_Audio_Datas+14), *(pt_Audio_Datas+15));
	set_Subchunk1Size 	(Number, *(pt_Audio_Datas+16), *(pt_Audio_Datas+17), *(pt_Audio_Datas+18), *(pt_Audio_Datas+19));
	set_AudioFormat 	(Number, *(pt_Audio_Datas+20), *(pt_Audio_Datas+21)); 
	set_NumChannels 	(Number, *(pt_Audio_Datas+22), *(pt_Audio_Datas+23));
	set_SampleRate 		(Number, *(pt_Audio_Datas+24), *(pt_Audio_Datas+25), *(pt_Audio_Datas+26), *(pt_Audio_Datas+27));
	set_ByteRate 		(Number, *(pt_Audio_Datas+28), *(pt_Audio_Datas+29), *(pt_Audio_Datas+30), *(pt_Audio_Datas+31));
	set_BlockAlign 		(Number, *(pt_Audio_Datas+32), *(pt_Audio_Datas+33));
	set_BitsPerSample 	(Number, *(pt_Audio_Datas+34), *(pt_Audio_Datas+35));
	set_Subchunk2ID 	(Number, *(pt_Audio_Datas+36), *(pt_Audio_Datas+37), *(pt_Audio_Datas+38), *(pt_Audio_Datas+39));
	set_Subchunk2Size 	(Number, *(pt_Audio_Datas+40), *(pt_Audio_Datas+41), *(pt_Audio_Datas+42), *(pt_Audio_Datas+43));

	set_StartAdress 	(Number);
	set_EndAdress 		(Number);	
	set_AudioStartAdress(Number);
	set_AudioEndAdress 	(Number); 
	set_NumberOfSamples (Number);
	set_AdressOfLastFile(Number);
	set_AdressOfNextFile(Number);
}

//-------------------------------------------------------------------
/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  copy_all
  *
  * Diese Funktion speichert die Format in das im Struktarray
  * Titels vorgesehene Feld
  * Das Array wird durch den jeweiligen Titel bestimmt
  *
  * \param	parameter   
  * \return	            none
  *
  */


/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  CopyStruck
  *
  * Diese Funktion Kopiert einen Strukt in einen anderen
  *
  * \param	parameter   uint8_t NumberOldStruckt, uint8_t NumberNewStruckt
  * \return	            none
  *
  */

void CopyStruck (uint8_t NumberOldStruckt, uint8_t NumberNewStruckt)
{
	#ifdef KOPIE_ON
	uint16_t u16temp;
	uint32_t u32temp;

	//BIG
	//(NumberNewStruckt, (uint8_t)u32temp, (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 24));
	//Little
	//(NumberNewStruckt, (uint8_t)(u32temp >> 24), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 8), (uint8_t)u32temp);
	//(NumberNewStruckt, (uint8_t)(u32temp >> 8), (uint8_t)u32temp);


	u32temp = get_ChunkID(NumberOldStruckt);
	set_ChunkID 		(NumberNewStruckt, (uint8_t)(u32temp >> 24), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 8), (uint8_t)u32temp);
	
	u32temp = get_ChunkSize (NumberOldStruckt);
	set_ChunkSize 		(NumberNewStruckt, (uint8_t)u32temp, (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp) >>24);
	
	u32temp = get_Format  (NumberOldStruckt);
	set_Format 			(NumberNewStruckt, (uint8_t)(u32temp >> 24), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 8), (uint8_t)u32temp);
	
	u32temp = get_Subchunk1ID   (NumberOldStruckt);
	set_Subchunk1ID 	(NumberNewStruckt, (uint8_t)(u32temp >> 24), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 8), (uint8_t)u32temp);
	
	u32temp = get_Subchunk1Size   (NumberOldStruckt);
	set_Subchunk1Size 	(NumberNewStruckt, (uint8_t)u32temp , (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp>>24));
	
	u16temp = get_AudioFormat   (NumberOldStruckt);
	set_AudioFormat 	(NumberNewStruckt, (uint8_t)u16temp, (uint8_t)u16temp >> 8);

	u16temp = get_NumChannels   (NumberOldStruckt);
	set_NumChannels 	(NumberNewStruckt, (uint8_t)u16temp, (uint8_t)u16temp >> 8);
	
	u32temp = get_SampleRate   (NumberOldStruckt);
	set_SampleRate 		(NumberNewStruckt, (uint8_t)u32temp , (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp>>24));
	
	u32temp = get_ByteRate   (NumberOldStruckt);
	set_ByteRate 		(NumberNewStruckt, (uint8_t)u32temp , (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp>>24));
	
	u16temp = get_BlockAlign   (NumberOldStruckt);
	set_BlockAlign 		(NumberNewStruckt, (uint8_t)u16temp, (uint8_t)u16temp >> 8);
	
	u16temp = get_BitsPerSample   (NumberOldStruckt);
	set_BitsPerSample 	(NumberNewStruckt, (uint8_t)u16temp, (uint8_t)u16temp >> 8);
	
	u32temp = get_Subchunk2ID   (NumberOldStruckt);
	set_Subchunk2ID 	(NumberNewStruckt, (uint8_t)(u32temp >> 24), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp >> 8), (uint8_t)u32temp);
	
	u32temp = get_Subchunk2Size   (NumberOldStruckt);
	set_Subchunk2Size 	(NumberNewStruckt, (uint8_t)u32temp , (uint8_t)(u32temp >> 8), (uint8_t)(u32temp >> 16), (uint8_t)(u32temp>>24));
	
	set_StartAdress 	(NumberNewStruckt);
	set_EndAdress 		(NumberNewStruckt);	
	set_AudioStartAdress(NumberNewStruckt);
	set_AudioEndAdress 	(NumberNewStruckt); 
	set_NumberOfSamples (NumberNewStruckt);
	set_AdressOfLastFile(NumberNewStruckt);
	set_AdressOfNextFile(NumberNewStruckt);	
	#endif
}

//---------------------------------------------------------------------------

/********************************************************************
*********************************************************************
********************************************************************/

/**
  * \brief  ResetAdressDatas
  *
  * Diese Erneuert die Adressdaten anch der Monokonvertierung
  *
  * \param	parameter   uint8_t NumberNewStruckt
  * \return	            none
  *
  */

void ResetAdressDatas (uint8_t NumberNewStruckt)
{
    #ifdef CLEAR_ON
	set_StartAdress 	(NumberNewStruckt);
	set_EndAdress 		(NumberNewStruckt);	
	set_AudioStartAdress(NumberNewStruckt);
	set_AudioEndAdress 	(NumberNewStruckt); 
	set_NumberOfSamples (NumberNewStruckt);
	set_AdressOfLastFile(NumberNewStruckt);
	set_AdressOfNextFile(NumberNewStruckt);	
	#endif
}


void StrucktClearAll (void)
{
	#ifdef CLEAR_ON
	uint8_t temp;
	for(temp = 0x00 ; temp < MAX_TITELS ; temp++)
	{
		set_ChunkID 		(temp, 0 , 0 , 0 , 0 );
		set_ChunkSize 		(temp, 0 , 0 , 0 , 0 );
		set_Format 			(temp, 0 , 0 , 0 , 0 );
		set_Subchunk1ID 	(temp, 0 , 0 , 0 , 0 );
		set_Subchunk1Size 	(temp, 0 , 0 , 0 , 0 );
		set_AudioFormat 	(temp, 0 , 0 ); 
		set_NumChannels 	(temp, 0 , 0 );
		set_SampleRate 		(temp, 0 , 0 , 0 , 0 );
		set_ByteRate 		(temp, 0 , 0 , 0 , 0 );
		set_BlockAlign 		(temp, 0 , 0 );
		set_BitsPerSample 	(temp, 0 , 0 );
		set_Subchunk2ID 	(temp, 0 , 0 , 0 , 0 );
		set_Subchunk2Size 	(temp, 0 , 0 , 0 , 0 );
	
		set_StartAdress 	(temp);
		set_EndAdress 		(temp);	
		set_AudioStartAdress(temp);
		set_AudioEndAdress 	(temp); 
		set_NumberOfSamples (temp);
		set_AdressOfLastFile(temp);
		set_AdressOfNextFile(temp);
	}
	#endif
}

//--------------------------------------------------------------------------------

void init_PageTabel(void)
{
	uint16_t temp;
	for(temp = 0x00 ; temp <MAX_TITELS*36 ; temp++)
	{
		u16VirtAddVarTab[temp] = temp;
	}
}

uint8_t get_EEPROMNumberOfTitels(void)
{
 	uint16_t tTitel = 0x0000;
	uint16_t valid;
	valid = EE_ReadVariable(u16VirtAddVarTab[NUMBEROFTITELS], &(tTitel));
	if(valid == 0x0000)
	{
		return tTitel;
	}
	else
	{
		return 0xFF;
	}
}

void set_EEPROMNumberOfTitels (uint8_t Number)
{
	EE_WriteVariable(u16VirtAddVarTab[NUMBEROFTITELS],(uint16_t)Number);
}


void CopyStrucktToEEPROM (uint8_t Number)
{
	#ifdef COPY_ON
	uint8_t VirStartAdress = 1 + Number * 36;
	uint16_t Temp_high;
	uint32_t Temp_low;

	Temp_low = get_ChunkID(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;

	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ChunkID_P1], Temp_high);
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ChunkID_P2],	Temp_low);

	Temp_low = get_ChunkSize(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			  
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ChunkSize_P1],	Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ChunkSize_P2],	Temp_low);
	
	Temp_low = get_Format(Number);
	Temp_high = (Temp_low >> 16);
		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Format_P1],		Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Format_P2],		Temp_low);
	
	Temp_low = get_Subchunk1ID(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1ID_P1],Temp_high);		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1ID_P2],Temp_low);
	
	Temp_low = get_Subchunk1Size(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1Size_P1],Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1Size_P2],Temp_low);

		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AudioFormat_P],get_AudioFormat(Number));
	
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + NumChannels_P],get_NumChannels(Number));
	
	Temp_low = get_SampleRate(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + SampleRate_P1],	Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + SampleRate_P2],	Temp_low);
	
	Temp_low = get_ByteRate(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ByteRate_P1],	Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + ByteRate_P2],	Temp_low);
	
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + BlockAlign_P],get_BlockAlign(Number));
	
				 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + BitsPerSample_P],get_BitsPerSample(Number));
	
	Temp_low = get_Subchunk2ID(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2ID_P1],Temp_high);		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2ID_P2],Temp_low);
	
	Temp_low = get_Subchunk2Size(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2Size_P1],Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2Size_P2],Temp_low);
	
	Temp_low = get_StartAdress(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + StartAdress_P1],Temp_high);		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + StartAdress_P2],Temp_low);
	
	Temp_low = get_EndAdress(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
			 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + EndAdress_P1],Temp_high);		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + EndAdress_P2],Temp_low);	
	
	Temp_low = get_AudioStartAdress(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AudioStartAdress_P1],Temp_high); 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AudioStartAdress_P2],Temp_low); 

	Temp_low = get_AudioEndAdress(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;

	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AudioEndAdress_P1],Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AudioEndAdress_P2],Temp_low);	
	
	Temp_low = get_NumberOfSamples(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + NumberOfSamples_P1],Temp_high);	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + NumberOfSamples_P2],Temp_low);
	
	Temp_low = get_AdressOfLastFile(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
		 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AdressOfLastFile_P1],Temp_high);
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AdressOfLastFile_P2],Temp_low);
	
	Temp_low = get_AdressOfNextFile(Number);
	Temp_high = (Temp_low >> 16);
	Temp_low = (uint16_t)Temp_low;
	 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AdressOfNextFile_P1],Temp_high); 
	EE_WriteVariable(u16VirtAddVarTab[VirStartAdress + AdressOfNextFile_P2],Temp_low); 
	#endif
}




void CopyEEPROMToStruckt (uint8_t Number)
{
 #ifdef COPY_ON
	uint8_t VirStartAdress = 1 + Number * 36;

	uint16_t Temp_low;
	uint32_t Temp_high;

	uint8_t Byte1; //High
	uint8_t Byte2;
	uint8_t Byte3;
	uint8_t Byte4; //Low

	//---------------------------------------------------------

	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ChunkID_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ChunkID_P2], &(Temp_low));

	Byte2 = (uint8_t)Temp_high;
	Byte4 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte1 = (uint8_t)Temp_high;
	Byte3 = (uint8_t)Temp_low;

	set_ChunkID(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------

	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ChunkSize_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ChunkSize_P2], &(Temp_low));

	Byte3 = (uint8_t)Temp_high;
	Byte1 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte4 = (uint8_t)Temp_high;
	Byte2 = (uint8_t)Temp_low;

	set_ChunkSize(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Format_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Format_P2], &(Temp_low));

	Byte2 = (uint8_t)Temp_high;
	Byte4 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte1 = (uint8_t)Temp_high;
	Byte3 = (uint8_t)Temp_low;

	set_Format(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1ID_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1ID_P2], &(Temp_low));

	Byte2 = (uint8_t)Temp_high;
	Byte4 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte1 = (uint8_t)Temp_high;
	Byte3 = (uint8_t)Temp_low;

	set_Subchunk1ID(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1Size_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk1Size_P2], &(Temp_low));

	Byte3 = (uint8_t)Temp_high;
	Byte1 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte4 = (uint8_t)Temp_high;
	Byte2 = (uint8_t)Temp_low;

	set_Subchunk1Size(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + AudioFormat_P], (uint16_t *)&(Temp_high));

	Byte1 = (uint8_t)Temp_high;
	Temp_high = (Temp_high >> 8);
	Byte2 = (uint8_t)Temp_high;

	set_AudioFormat(Number, Byte1, Byte2);

	//--------------------------------------------------------- 
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + NumChannels_P], (uint16_t *)&(Temp_high));

	Byte1 = (uint8_t)Temp_high;
	Temp_high = (Temp_high >> 8);
	Byte2 = (uint8_t)Temp_high;

	set_NumChannels(Number, Byte1, Byte2);

	//--------------------------------------------------------- 
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + SampleRate_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + SampleRate_P2], &(Temp_low));

	Byte3 = (uint8_t)Temp_high;
	Byte1 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte4 = (uint8_t)Temp_high;
	Byte2 = (uint8_t)Temp_low;

	set_SampleRate(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------			 	
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ByteRate_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + ByteRate_P2], &(Temp_low));

	Byte3 = (uint8_t)Temp_high;
	Byte1 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte4 = (uint8_t)Temp_high;
	Byte2 = (uint8_t)Temp_low;

	set_ByteRate(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------	
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + BlockAlign_P], (uint16_t *)&(Temp_high));

	Byte1 = (uint8_t)Temp_high;
	Temp_high = (Temp_high >> 8);
	Byte2 = (uint8_t)Temp_high;

	set_BlockAlign(Number, Byte1, Byte2);

	//---------------------------------------------------------
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + BitsPerSample_P], (uint16_t *)&(Temp_high));

	Byte1 = (uint8_t)Temp_high;
	Temp_high = (Temp_high >> 8);
	Byte2 = (uint8_t)Temp_high;

	set_BitsPerSample(Number, Byte1, Byte2);

	//---------------------------------------------------------		
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2ID_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2ID_P2], &(Temp_low));

	Byte2 = (uint8_t)Temp_high;
	Byte4 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte1 = (uint8_t)Temp_high;
	Byte3 = (uint8_t)Temp_low;

	set_Subchunk2ID(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------
	
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2Size_P1], (uint16_t *)&(Temp_high));
	EE_ReadVariable(u16VirtAddVarTab[VirStartAdress + Subchunk2Size_P2], &(Temp_low));

	Byte3 = (uint8_t)Temp_high;
	Byte1 = (uint8_t)Temp_low;
	Temp_high = (Temp_high >> 8);
	Temp_low = (Temp_low >> 8);
	Byte4 = (uint8_t)Temp_high;
	Byte2 = (uint8_t)Temp_low;

	set_Subchunk2Size(Number, Byte1, Byte2, Byte3, Byte4);

	//---------------------------------------------------------
	
	set_StartAdress(Number);

	//---------------------------------------------------------	

	set_EndAdress(Number);

	//---------------------------------------------------------
	
	set_AudioStartAdress(Number);

	//---------------------------------------------------------

	set_AudioEndAdress(Number);

	//---------------------------------------------------------

	set_NumberOfSamples(Number);

	//---------------------------------------------------------
	
	set_AdressOfLastFile(Number);

	//---------------------------------------------------------

	set_AdressOfNextFile(Number);

	//---------------------------------------------------------
	#endif
}

//#pragma O0

#undef __INTERNAL_FLASH_C	
