/******************** (C) COPYRIGHT 2010 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V3.1.1
* Date               : 04/07/2010
* Description        : Virtual Com Port Demo main file
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "stm32f10x.h"
#include "usb_lib.h"
#include "usb_desc.h"
#include "hw_config.h"
#include "usb_pwr.h"
#include "global.h"
#include "init.h"
#include "menue.h"
#include "sub_menue.h"
#include "menue_GUI.h"
#include "spi_flash.h"
#include "eeprom.h"

#include "dsp.h"
#include "dma_user.h"
#include "timer_pwm.h"
#include "usb_endp.h"



#pragma O3

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Extern variables ----------------------------------------------------------*/


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name  : main.
* Description    : Main routine.
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/

/**
  * \brief  main
  *
  * In der Mainroutine wird das Management der einzellnen Funktionsgruppen 
  * und der menfhrung vorgenommen
  * \param	parameter   none
  * \return	            none
  *
  */

int main(void)

{  
  init_all();

  // Sinus (uint16_t u16SinusFrequenz, uin16_t u16FixSampling0OrQuantisation, uint16_t u16FixValue)
//	Sinus (1000, 0, 44100,50); 
  
  while (1)
  {
/**********************************************************
 Speichern der Daten
**********************************************************/	
  	if(u8BufferFilled > 0x00 || u8EndOfFile == 0xFF)
	{
		SaveRecivedDatas();
		u8EndOfFile = 0x00;
	}

/**********************************************************
 Empfang von Steuerzinformationen
**********************************************************/	
  	else if ((u32Count_Out != 0) && (bDeviceState == CONFIGURED))
    {
      USB_To_User_Buffer_Send_Data(&u8Buffer_Out[0], u32Count_Out); 
      u32Count_Out = 0;
    }
/**********************************************************
 Abarbeitung der Steuerzinformationen
**********************************************************/		
	else
	{
		/**********************************************************
		 Intro Ausgeben
		**********************************************************/	
	  	if(u8User_Commands_From_PC == 0x0D)
		{
			if(u8User_Sub_Commands_From_PC != TEST_TONE_ON)
			{				
	   		 	GUIUserCommandsFromPC();
			}
			else
			{
				GUIUserCommandsForTestSinus();	
			}
		}
	
		/**********************************************************
		 GUI um neue Audiodateien zu landen
		**********************************************************/
	   	else if(u8User_Sub_Commands_From_PC == WILL_SEND_AUDIO_FILE)
	   	{
	   		u32 FlashID;
			FlashID = SPI_FLASH_ReadID(); //FlashID muss sein : 0x00202017 !!!
	
			if (FlashID == 0x00202017)
			{
				u16Titel_Counter++;
		   		GUIWillSendAudioFileSDOK();
			}
			else
			{
				GUIWillSendAudioFileSDNotOK();
			}
	   }
	   /**********************************************************
		 GUI um neue Smaplingfrequenz
		**********************************************************/
	   else if(u8User_Sub_Commands_From_PC == WILL_SEND_NEW_SAMPLINGFREQUENZ)
	   {
	   		GUIWillSendNewSamplingfrequenz();
	   }
	
		/**********************************************************
		 GUI um neue Quantisierungsstufenanzahl zu setzen
		**********************************************************/
	   else if(u8User_Sub_Commands_From_PC == WILL_SEND_QUANTISATION_STEPS)
	   {																	   
	   		//Change Sampelstaps
			GUIWillSendNewQuantisationSteps();
	   }
	
		/**********************************************************
		 GUI um neue Speicher zu lschen
		**********************************************************/
	   else if(u8User_Sub_Commands_From_PC == ERASE_ALL)
	   {															
	   		//Change Sampelstaps
			GUIEraseAllStart();

			Erase_all();
			SPI_FLASH_BulkErase();
			StrucktClearAll();
			u16Titel_Counter = 0x00;

			GUIEraseAllFinish();
	   }
	   /**********************************************************
		 GUI um neue Infopage auszugeben
		**********************************************************/
	   	else if(u8User_Sub_Commands_From_PC == INFO_PAGE)
		{
			GUIInfoPage();	
		}
	  
		/**********************************************************
		 GUI um einen Titel an den PC zu senden
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == RETURN_ONE_TITLE)
		{
			if(u16Titel_Counter >0)
			{	
				GUIReturnOneTitel(GUIGetUserTitelWish());
			}
			else
			{
				GUIReturnNoTitelOnFlash();
			}
		}

		/**********************************************************
		 GUI um alle Titel an den PC zu senden
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == RETURN_ALL_TITELS)
		{
			if(u16Titel_Counter >0)
			{	
				GUIReturnAllTitels();
			}
			else
			{
				GUIReturnNoTitelOnFlash();
			}
		}
		/**********************************************************
		 GUI um Titel in Mono zu wandeln
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == STEREO_TO_MONO_CONVERT)
		{
			GUIConvertStereoToMono(GUIGetUserTitelWish());
		}
		/**********************************************************
		 GUI um Titel abzuspielen
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == PLAY_TITLE)
		{
			GUIPlayTitel(GUIGetUserTitelWish());	
		}
		/**********************************************************
		 GUI um Testton an oder abzuschalten
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == TEST_TONE_CONTROL)
		{
			GUIUserCommandsForTestSinus();	
			u8User_Sub_Commands_From_PC = TEST_TONE_ON;
		}
		/**********************************************************
		 GUI fr Testton
		**********************************************************/
		else if(u8User_Sub_Commands_From_PC == TEST_TONE_ON)
		{
			TestToneSubMenue();
		}		
	} 
  }
}

#ifdef USE_FULL_ASSERT
/*******************************************************************************
* Function Name  : assert_failed
* Description    : Reports the name of the source file and the source line number
*                  where the assert_param error has occurred.
* Input          : - file: pointer to the source file name
*                  - line: assert_param error line source number
* Output         : None
* Return         : None
*******************************************************************************/
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {}
}

//#pragma O0

#endif	
